@@ -5,12 +5,15 @@
 
 package org.wildfly.clustering.weld.ejb.component.stateful;
 
-import org.infinispan.protostream.SerializationContext;
+import org.kohsuke.MetaInfServices;
 import org.wildfly.clustering.marshalling.protostream.AbstractSerializationContextInitializer;
+import org.wildfly.clustering.marshalling.protostream.SerializationContext;
+import org.wildfly.clustering.marshalling.protostream.SerializationContextInitializer;
 
 /**
  * @author Paul Ferraro
  */
+@MetaInfServices(SerializationContextInitializer.class)
 public class StatefulComponentSerializationContextInitializer extends AbstractSerializationContextInitializer {
 
     public StatefulComponentSerializationContextInitializer() {
