@@ -72,7 +72,7 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
     private final boolean isFullDistribution = AssumeTestGroupUtil.isFullDistribution();
     private final boolean isPreviewGalleonPack = AssumeTestGroupUtil.isWildFlyPreview();
 
-    private static final String MAJOR = "32.";
+    private static final String MAJOR = "34.";
 
     /**
      * Maintains the list of expected extensions for each host-exclude name for previous releases.
@@ -199,15 +199,20 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
                 ), true),
         WILDFLY_30_0("WildFly30.0", WILDFLY_29_0, List.of(), List.of(), true),
         WILDFLY_31_0("WildFly31.0", WILDFLY_30_0, List.of(), List.of(), true),
-        CURRENT(MAJOR, WILDFLY_31_0, getCurrentAddedExtensions(), getCurrentRemovedExtensions(), true);
+        WILDFLY_32_0("WildFly32.0", WILDFLY_31_0, List.of(
+                "org.wildfly.extension.mvc-krazo"
+        ), List.of(), true),
+        WILDFLY_33_0("WildFly33.0", WILDFLY_32_0, List.of(), List.of(), true),
+        CURRENT(MAJOR, WILDFLY_33_0, getCurrentAddedExtensions(), getCurrentRemovedExtensions(), true);
 
         private static List<String> getCurrentAddedExtensions() {
             // If an extension is added to this list, also check if it is supplied only by wildfly-galleon-pack. If so, add it also
             // to the internal mpExtensions Set defined on this class.
             // Don't add here extensions supplied only by the wildfly-preview-feature-pack because we are not tracking different releases
             // of wildfly preview. In such a case, add them to previewExtensions set defined below.
-            return List.of("org.wildfly.extension.elytron.jaas-realm", "org.wildfly.extension.mvc-krazo");
+            return List.of();
         }
+
         private static List<String> getCurrentRemovedExtensions() {
             // TODO If we decide to remove these modules from WFP, uncomment this.
             // See https://issues.redhat.com/browse/WFLY-16686
@@ -231,7 +236,7 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
         private final boolean supported;
 
         // List of extensions added by the wildfly-galleon-pack
-        private final Set<String> mpExtensions = new HashSet<>(Arrays.asList(
+        private final Set<String> expansionExtensions = new HashSet<>(Arrays.asList(
                 "org.wildfly.extension.micrometer",
                 "org.wildfly.extension.microprofile.config-smallrye",
                 "org.wildfly.extension.microprofile.health-smallrye",
@@ -239,20 +244,24 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
                 "org.wildfly.extension.microprofile.fault-tolerance-smallrye",
                 "org.wildfly.extension.microprofile.jwt-smallrye",
                 "org.wildfly.extension.microprofile.openapi-smallrye",
+                "org.wildfly.extension.microprofile.opentracing-smallrye",
                 "org.wildfly.extension.microprofile.reactive-messaging-smallrye",
                 "org.wildfly.extension.microprofile.reactive-streams-operators-smallrye",
                 "org.wildfly.extension.microprofile.lra-coordinator",
                 "org.wildfly.extension.microprofile.lra-participant",
-                "org.wildfly.extension.microprofile.telemetry"
+                "org.wildfly.extension.microprofile.telemetry",
+                "org.wildfly.extension.mvc-krazo",
+                "org.wildfly.extension.opentelemetry"
         ));
 
-        // List of extensions added only by the WildFly Preview
+        // List of extensions added only by WildFly Preview.
         // We do not track changes between different versions of WildFly Preview.
         // From the point of view of this test, all extensions added in WildFly Preview are always extensions
         // added in the latest release of WildFly Preview. It is out of the scope of Host Exclusion test
         // to compute on which WildFly Preview was added such a new extension and track the Host Exclusions between
         // different WildFly Preview releases.
         private final Set<String> previewExtensions = new HashSet<>(Arrays.asList(
+                "org.wildfly.extension.jakarta.data"
         ));
 
         ExtensionConf(String name, ExtensionConf parent, boolean supported) {
@@ -310,7 +319,7 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
                 this.extensions.addAll(previewExtensions);
             }
             if (!isFullDistribution && !isPreview) {
-                return diff.apply(extensions, mpExtensions);
+                return diff.apply(extensions, expansionExtensions);
             }
             return extensions;
         }
@@ -398,13 +407,13 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
             List<String> excludedExtensions = prop.getValue().get(EXCLUDED_EXTENSIONS)
                     .asListOrEmpty()
                     .stream()
-                    .map(p -> p.asString())
+                    .map(ModelNode::asString)
                     .collect(Collectors.toList());
 
             //check duplicated extensions
-            Assert.assertTrue(String.format (
-                            "There are duplicated extensions declared for %s host-exclude", name),
-                    excludedExtensions.size() == new HashSet<>(excludedExtensions).size()
+            Assert.assertEquals(String.format("There are duplicated extensions declared for %s host-exclude", name),
+                    excludedExtensions.size(),
+                    new HashSet<>(excludedExtensions).size()
             );
 
             //check we have defined the current host-exclude configuration in the test
@@ -458,6 +467,12 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
         Iterator<String> moduleNames = ml.iterateModules((String) null, true);
         while (moduleNames.hasNext()) {
             String moduleName = moduleNames.next();
+            if (moduleName.equals("org.wildfly.extension.elytron.jaas-realm")) {
+                // Temporary workaround until https://issues.redhat.com/browse/WFCORE-6834 gets fixed
+                // org.wildfly.extension.elytron.jaas-realm is not a WildFly extension, so even if it supplies
+                // a META-INF/services/org.jboss.as.controller.Extension file, we should ignore it.
+                continue;
+            }
             Module module;
             try {
                 module = ml.loadModule(moduleName);
@@ -480,8 +495,10 @@ public class HostExcludesTestCase extends BuildConfigurationTestBase {
             return f.isDirectory() && !f.isHidden();
         };
         List<File> result = new ArrayList<>();
-        for (Path path : Files.newDirectoryStream(layersRoot, filter)) {
-            result.add(path.toFile());
+        try(DirectoryStream<Path> stream = Files.newDirectoryStream(layersRoot, filter)) {
+            for (Path path : stream) {
+                result.add(path.toFile());
+            }
         }
         return result.toArray(new File[0]);
     }
